# ApplicationSecurity

Configuration of an Application's security model. This includes details such as http security headers and certificate transparency settings. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**http** | [**HTTPSecuritySettings**](HTTPSecuritySettings.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


